@@ -1,18 +1,18 @@
 /* ScummVM Tools
  *
- * ScummVM Tools is the legal property of its developers, whose
- * names are too numerous to list here. Please refer to the
- * COPYRIGHT file distributed with this source distribution.
+ * ScummVM Tools is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
  *
  * Additionally this file is based on the ScummVM source code.
  * Copyright information for the ScummVM source code is
  * available in the COPYRIGHT file of the ScummVM source
  * distribution.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #ifndef COMMON_ENDIAN_H
@@ -29,6 +29,8 @@
 
 #include "common/scummsys.h"
 
+#define MKTAG(a0,a1,a2,a3) ((uint32)((a3) | ((a2) << 8) | ((a1) << 16) | ((a0) << 24)))
+
 #if defined(INVERSE_MKID)
 #define MKID_BE(a) ((uint32) \
 		(((a) >> 24) & 0x000000FF) | \
@@ -52,6 +54,17 @@ static inline uint16 SWAP_16(uint16 a) {
 	return uint16(((a >> 8) & 0xFF) | ((a << 8) & 0xFF00));
 }
 
+#if defined(SCUMM_BIG_ENDIAN)
+	#define FROM_LE_32(a) SWAP_32(a)
+	#define FROM_LE_16(a) SWAP_16(a)
+	#define TO_LE_32(a) SWAP_32(a)
+	#define TO_LE_16(a) SWAP_16(a)
+#else
+	#define FROM_LE_32(a) ((uint32)(a))
+	#define FROM_LE_16(a) ((uint16)(a))
+	#define TO_LE_32(a) ((uint32)(a))
+	#define TO_LE_16(a) ((uint16)(a))
+#endif
 
 FORCEINLINE uint16 READ_LE_UINT16(const void *ptr) {
 	const byte *b = (const byte *)ptr;
